Tutorials
=========

The tutorials below showcase complete Coord2Region workflows. Each entry is
an executable :mod:`sphinx-gallery` example that can be explored interactively
in the gallery. To keep the documentation build lightweight, the examples
skip large dataset downloads when the files are not already available locally.

.. toctree::
   :maxdepth: 1

   auto_examples/plot_meg_source_localization
   auto_examples/plot_ieeg_electrode_localization
   auto_examples/plot_fmri_coord_to_region
